package com.ozs.pm.service;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ozs.common.core.domain.AjaxResult;
import com.ozs.base.domain.vo.BaseExpertVo;
import com.ozs.pm.doman.PmDemand;
import com.ozs.pm.doman.vo.requestVo.*;
import com.ozs.pm.doman.vo.responseVo.PmDemandResVo;
import com.ozs.pm.doman.vo.responseVo.PmFlowChartResVo;
import com.ozs.system.domain.SysFileRef;

import java.util.List;


/**
 * 采购需求Service接口
 *
 * @author ruoyi
 * @date 2023-01-16
 */
public interface IPmDemandService extends IService<PmDemand>
{
    /**
     * 查询采购需求
     *
     * @param demandId 采购需求主键
     * @return 采购需求
     */
    PmDemandResVo selectPmDemandByDemandId(Long demandId,String detailType);

    /**
     * 查询采购需求列表
     *
     * @param pmDemandReqVo 采购需求
     * @return 采购需求集合
     */
    IPage<PmDemandResVo> selectPmDemandList(PmDemandReqVo pmDemandReqVo,int reqType);


    /**
     * 需求建档
     *
     * @param pmBookBuildingReqVo 需求建档
     * @return 结果
     */
    boolean bookBuilding(PmBookBuildingReqVo pmBookBuildingReqVo);

    /**
     * 查看流程图
     *
     * @param demandId 采购需求主键
     * @return 采购需求
     */
    Object viewFlowChart(Long demandId);

    /**
     * 查看流程图
     *
     * @param demandId 采购需求主键
     * @return 采购需求
     */
    PmFlowChartResVo getModuleInfo(Long demandId, String moduleName);

    /**
     * 提交采购需求
     *
     * @param pmDemandReqVo
     * @return 结果
     */
    boolean commit(PmDemandReqVo pmDemandReqVo);

    /**
     * 审核采购需求通过
     *
     * @param pmDemandReqVo
     * @return 结果
     */
    boolean reviewTo(PmDemandReqVo pmDemandReqVo);

    /**
     * 审核采购需求退回
     *
     * @param pmDemandReqVo
     * @return 结果
     */
    boolean reviewReturn(PmDemandReqVo pmDemandReqVo);

    /**
     * 下达任务
     *
     * @param pmDemandReqVo
     * @return 结果
     */
    boolean releaseTask(PmDemandReqVo pmDemandReqVo);

    boolean uploadFile(Long redId,Integer fileType, List<SysFileRef> sysFileRefs,String upateBy);

    boolean insertPmReleaseAnnouncement(PmReleaseAnnouncementReqVo pmReleaseAnnouncementReqVo) throws Exception;

    boolean insertExpertBatch(PmBaseExpertFillReqVo pmBaseExpertFillReqVo) throws Exception;

    boolean extractExpertBatch(PmBaseExpertExtractReqVo pmBaseExpertExtractReqVo) throws Exception;

    boolean insertBidOpeningBatch(PmBidOpeningFillReqVo pmBidOpeningFillReqVo) throws Exception;

    boolean insertPmBidWinning(PmBidWinningReqVo pmBidWinningReqVo) throws Exception;

    boolean updatePmBidWinning(PmBidWinningReqVo pmBidWinningReqVo) throws Exception;

    boolean insertPmBidFailure(PmBidFailureReqVo pmBidFailureReqVo) throws Exception;

    boolean insertContractInfo(PmContractInfoReqVo pmContractInfoReqVo) throws Exception;

    boolean insertProjectConstruction(PmProjectConstructionReqVo pmProjectConstructionReqVo) throws Exception;

    /**
     * 通过需求ID列表 查询采购执行列表 sunhh
     * @param demandIdList
     * @return
     */
    List<PmDemand> selectByDemandIdList(List<Integer> demandIdList);

    /**
     * 专家库--查询抽取专家列表 非必传条件：专家名称，开始结束时间 sunhh
     *
     * @param baseExpertVo
     * @return
     */
    List<PmDemand> selectExtractionExpert(BaseExpertVo baseExpertVo);

    /**
     * 查询需求单位首页待办事项（需求待提交）
     *
     * @return
     */
    AjaxResult demandWaitCommit();

    /**
     * 查询需求单位首页待办事项（合同待填制）
     *
     * @return
     */
    AjaxResult contractWaitFilled();

    /**
     * 查询需求单位首页待办事项（项目建设待完成）
     *
     * @return
     */
    AjaxResult projectWaitFinish();
}
